@@ -4,7 +4,7 @@ import time
 from datetime import timedelta
 from typing import List
 
-from dbnd import pipeline, task
+from dbnd import log_metric, pipeline, task
 from dbnd_test_scenarios.pipelines import bad_pipeline
 
 
@@ -44,5 +44,12 @@ def pipe_of_long_tasks(num_per_iteration=3, iterations=1, with_failure=False):
     return p_input
 
 
+@task
+def task_write_n_metrics(n=10):
+    for i in range(n):
+        log_metric(str(i), i)
+    print("done")
+
+
 def user_exception_task(p_input=""):
     raise Exception("An explicit error for crushing this pipeline.")
