@@ -1,16 +1,18 @@
 import pyspark.sql as spark
 
 from dbnd import output, parameter
-from dbnd.tasks import spark_task
+from dbnd_spark import spark_task
+from targets.types import PathStr
 
 
 @spark_task(result=output[spark.DataFrame])
 def word_count_inline(
     text=parameter.data.txt[spark.DataFrame], counters=output.txt.data
 ):
-    # type:  (spark.DataFrame, Target) -> spark.DataFrame
+    # type:  (spark.DataFrame, PathStr) -> spark.DataFrame
     from operator import add
-    from dbnd._core.commands import get_spark_session
+
+    from dbnd_spark import get_spark_session
 
     lines = text.rdd.map(lambda r: r[0])
     counts = (
